﻿© Fluke. All Rights Reserved.                               MET/CAL Procedure
=============================================================================
INSTRUMENT:            Sub IEEE-488.2 Message Available IEEE
INSTRUMENT:            Sub IEEE-488.2 Message Available IEEE (No ESR Err Chk)
DATE:                  2011-04-29 10:53:58
AUTHOR:                Fluke
REVISION:              $Revision: 1.2 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       1
NUMBER OF LINES:       145
=============================================================================
#
#  Text Source:
#    $RCSfile: sub_ieee488_2_message_available_ieee.txt,v $
#    $Date: 2011/01/31 17:08:42 $
#
#  Compatibility:
#        MET/CAL 7.20 SP1 (7.20x) or later
#
#  Subprocedures:
#        None
#
#  Required Files:
#        None
#
#  (No ESR Err Chk):
#    Waits for Message Available (MAV). Disregards returned errors,
#    waiting only for the MAV bit to be set. Used, for example,
#    during ADJ and VER of 9500() Base Unit to avoid runtime errors
#    when the 9500 Base Unit or available Active Heads are past due
#    cal.
#
#  Variables Used:
#
#    Input:
#      @Cmd           Command string to send to UUT.
#
#      @MAV_Timeout   Timeout (milliseconds)
#
#      @Msg           Used to update the head message.
#
#    Output:
#      @Error         0 MAV bit in Status Byte (STB) is set
#                     1 if an error occurred
#
#  Example Usage:
#
#    7.006  MATH         @Msg = "Waiting for SELF TEST to complete"
#    7.007  MATH         @Cmd = "*TST?"; @MAV_Timeout = 90000
#    7.008  CALL         Sub IEEE-488.2 Message Available IEEE (No Chk Err)
#    7.009  JMPL         ERROR                       @Error
#           .
#           .
#           .
#    9.001  LABEL        ERROR
#
#  The copyright in this procedure is owned by Fluke Corporation.
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

  1.001  MATH         CheckForESR_Error = NOT(PSUBI("No ESR Err Chk"))
  1.002  MATH         MAV = 0; @Error = 0; ElapsedTime = 0

  1.003  IF           CheckForESR_Error
  1.004  IEEE         *SRE 0;*ESE 20;*CLS;[V @Cmd]
  1.005  ELSE
  1.006  IEEE         *SRE 0;*ESE 0;*CLS;[V @Cmd]
  1.007  ENDIF

  1.008  DO
  1.009  MATH         MEM2 = FTIME(ElapsedTime / 1000)
  1.010  HEAD         -2 [V @Msg] ([MEM2] has elapsed)
#  1.011  IEEE         *STB?[I]

  1.011  IF           CheckForESR_Error
# Serial poll the instrument until the MAV or ESB is set in the status byte.
  1.012  IEEE         [SPL 48]
  1.013  ELSE
# Serial poll the instrument until the MAV is set in the status byte.
  1.014  IEEE         [SPL 16]
  1.015  ENDIF

  1.016  MATH         STB = MEM

  1.017  IF           CheckForESR_Error

  1.018  IF           BIT(5, STB)
  1.019  IEEE         *ESR?[I]
  1.020  MATH         ESR = MEM

  1.021  IF           BIT(2, ESR)
  1.022  MATH         ErrMsg = "Query Error"
  1.023  ELSEIF       BIT(3, ESR)
  1.024  MATH         ErrMsg = "Device Dependent Error"
  1.025  ELSEIF       BIT(4, ESR)
  1.026  MATH         ErrMsg = "Execution Error"
  1.027  ELSEIF       BIT(5, ESR)
  1.028  MATH         ErrMsg = "Command Error"
  1.029  ELSE
  1.030  MATH         ErrMsg = "Unidentified error"
  1.031  ENDIF

  1.032  MATH         @Error = 1
  1.033  ENDIF        ; BIT(5, STB)

  1.034  ENDIF        ; NOT(PSUBI("No Chk Err"))

  1.035  IF           BIT(4, STB)
  1.036  MATH         MAV = 1
  1.037  ELSE

  1.038  IF           NOT(MAV || @Error)
  1.039  WAIT         [D1000]
  1.040  MATH         ElapsedTime = ElapsedTime + 1000

  1.041  IF           ElapsedTime > @MAV_Timeout
  1.042  OPBR         -z Timeout waiting for Message Available (MAV).
  1.042  OPBR
  1.042  OPBR         Do you wish to continue to wait?

  1.043  IF           MEM1
  1.044  MATH         ElapsedTime = 0
  1.045  MATH         ErrMsg = ""
  1.046  ELSE
  1.047  MATH         @Error = 1
  1.048  MATH         ErrMsg = "Timeout Error"
  1.049  ENDIF

  1.050  ENDIF        ; ElapsedTime > @MAV_Timeout

  1.051  ENDIF        ; NOT(MAV || @Error)

  1.052  ENDIF        ; BIT(4, MEM)

  1.053  UNTIL        MAV || @Error

  1.054  IF           @Error
  1.055  DISP         [V ErrMsg]
  1.055  DISP
  1.055  DISP         Select Advance to terminate procedure.
  1.056  END
  1.057  ENDIF

  1.058  HEAD         -2
  1.059  END
